# script to calculate biomass from all HF live tree data
# written by L. Nicoll and modified by A. Barker Plotkin
# Sept 2014
# modified November 2016 by A. Barker Plotkin
# the sources for most of these equations is described in Dropbox\HF C Synthesis\Writing\allometry-appendix-nov2016.doc and refines these compilations:
# 1) Harvard Forest Data Archive HF069, Biomass Inventories at Harvard Forest EMS Tower since 1993. hf069-17: allometric equations and species names
# 2) Eisen & Barker Plotkin 2013. J. Torrey Bot. Soc. 142(2):97-112. http://harvardforest.fas.harvard.edu/sites/harvardforest.fas.harvard.edu/files/publications/pdfs/Eisen_JournTorrey_2015.pdf,  Appendix I.
# 3) Jenkins GTR-NE-319. (http://lterdev.fsl.orst.edu/lter/pubs/pdf/gtr_pdfs/ne_gtr319.pdf)
# 4) substitute Adrien Finzi's fused equations for 14 of the 20 most common species, based on Jenkins' compilation.

#calculate biomass
biomassAF20<-function(species, dbh_cm=dbh){
  biomass<-0
  #if(species == "ABBA") {biomass = exp(-2.5356+2.4349*log(dbh_cm))} #Jenkins pine equation 
  if(species == "ABBA") {biomass = (exp(0.5958 + 2.4017*log(dbh_cm/2.54)))/2.2} #Jenkins (Young et al. 1980)
  if(species == "ACPE") {biomass = (exp(4.68 + 2.38 * log(dbh_cm)))/1000} #HF069 (Hocker & Early 1983)
  #if(species == "ACRU") {biomass = (exp(5.02 + 2.33 * log(dbh_cm)))/1000}
  if(species == "ACRU") {biomass = exp(-2.2202 + 2.3922*log(dbh_cm))} #Finzi
  #if(species == "ACSA") {biomass = 0.1008*(dbh_cm^2.5735) }
  if(species == "ACSA") {biomass = exp(-1.291 + 2.219*log(dbh_cm))} #Finzi
  if(species == "ACSC") {biomass = 0.2040*(dbh_cm^2.2524)  }#Acer spicatum, Ter-Mikaelian (Whittaker et al. 1974)
  if(species == "ACSP") {biomass = exp(-2.2202 + 2.3922*log(dbh_cm))} #Finzi ACRU, if the Acer species is undefined
  if(species == "ALIN") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation (red alder, but not speckled alder in Jenkins)
  #if(species == "BEAL") {biomass = (10^(2.1413 + 2.2683 * log10(dbh_cm)) + 10^(1.0535 + 2.7995 * log10(dbh_cm)))/1000 }
  if(species == "BEAL") {biomass = exp(-1.542 + 2.260*log(dbh_cm))} #Finzi
  if(species == "BELE") {biomass = (1.6542 * (dbh_cm/2.54)^2.6606)/2.2  } #HF069 (Ter-Mik, Brenneman)
  #if(species == "BENI") {biomass = exp(-1.9123+2.3651*(log(dbh_cm))) } NO Betual nigra - the one BENI is really BELE
  #if(species == "BEPA") {biomass = (exp(-0.1463825 + 2.896804 * log(dbh_cm/2.54)) + exp(-1.053626 + 2.249402 * log(dbh_cm/2.54)))/2.2 }
  if(species == "BEPA") {biomass = exp(-3.082 + 2.683*log(dbh_cm))} #Finzi
  #if(species == "BEPO") {biomass = (exp(0.6541776 + 2.529903 * log(dbh_cm/2.54)) + exp(-0.3969096 + 1.628732 * log(dbh_cm/2.54)))/2.2 }
  if(species == "BEPO") {biomass = exp(-1.835 + 2.309*log(dbh_cm))} #Finzi
  if(species == "BESP") {biomass = (1.6542 * (dbh_cm/2.54)^2.6606)/2.2  } #just the Betula lenta equation, if the Betula species is undefined
  if(species == "CACA") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation (don't see hornbeam in any compilation)
  #if(species == "CADE") {biomass = (exp(5.03 + 2.39 * log(dbh_cm)))/1000 } #HF069 uses QURU equation for CADE. . . not sure
  if(species == "CADE") {biomass = exp(-1.881 + 2.386*log(dbh_cm))} #Finzi QURU equation
  if(species == "CAGL") {biomass =  0.0763*dbh_cm^2.6209 } #Carya species, Wiant et al. 1977 in Ter-Mik
  if(species == "CAOV") {biomass =  0.0763*dbh_cm^2.6209 } #Carya species, Wiant et al. 1977 in Ter-Mik
  if(species == "CASP") {biomass =  0.0763*dbh_cm^2.6209 } #Carya species, Wiant et al. 1977 in Ter-Mik
  #if(species == "FAGR") {biomass = (10^(2.028 + 2.3981 * log10(dbh_cm)) + 10^(1.4182 + 2.5509 * log10(dbh_cm)))/1000 }
  if(species == "FAGR") {biomass = exp(-1.342 + 2.231*log(dbh_cm))} #Finzi
  #if(species == "FRAM") {biomass = 0.1063*(dbh_cm^2.4798)  }
  if(species == "FRAM") {biomass = exp(-1.381 + 2.208*log(dbh_cm))} #Finzi
  if(species == "FRNI") {biomass = 0.1634*dbh_cm^2.3480 }
  if(species == "HAVI") {biomass = (38.111 * (dbh_cm^2.9))/1000 } #HF069 (source mysterious: Smith & Brand 1984)
  if(species == "JUVI") {biomass = exp(-0.7152+1.7029*log(dbh_cm))   } #Jenkins woodland equation 
  if(species == "LASP") {biomass = (exp(0.8162 + 2.2453*log(dbh_cm/2.54)))/2.2} #Jenkins for tamarack (Young et al. 1980) 
  if(species == "LADE") {biomass = (exp(0.8162 + 2.2453*log(dbh_cm/2.54)))/2.2} #Jenkins for tamarack (Young et al. 1980)
  if(species == "MASP") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation
  if(species == "NYSY") {biomass = exp(-2.4800+2.4835*(log(dbh_cm))) }#Jenkins mixed hardwood equation, because the N. sylvatica equations in are for tiny trees or split by dbh class
  if(species == "OSVI") {biomass = exp(-2.4800+2.4835*log(dbh_cm))  } #Jenkins mixed hardwood equation 
  if(species == "PHSP") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation, Phellodendron sp.(cork tree)
  #if(species == "PI"  ) {biomass = exp(-2.0773+ 2.3323*(log(dbh_cm))) } #use Finzi Picea rubens equation
  #if(species == "PIAB") {biomass = (10^(2.1735+2.1936*log10(dbh_cm)))/1000  } #Siccama et al. 1994 for P. rubens
  #if(species == "PISP") {biomass = (10^(2.1735+2.1936*log10(dbh_cm)))/1000  } #Siccama et al. 1994 for P. rubens
  #if(species == "PIGL") {biomass = (exp(0.3960433 + 2.374645 * log(dbh_cm/2.54)) + exp(-1.351318 + 2.338385 * log(dbh_cm/2.54)))/2.2 } #HF069
  #if(species == "PIRE") {biomass = (exp(0.3078881 + 2.448125 * log(dbh_cm/2.54)) + exp(-1.508616 + 2.501085 * log(dbh_cm/2.54)))/2.2 }
  if(species == "PIRE") {biomass = exp(-2.076 + 2.317*log(dbh_cm))} #Finzi
  if(species=="PIRI" ) {biomass = 0.1040*(dbh_cm^2.3373) } #Pinus rigida, Whittaker & Woodwell 1968 (in Ter-Mik)
  #if(species == "PIRU") {biomass = exp(-2.0773+ 2.3323*(log(dbh_cm)))} 
  if(species == "PIRU") {biomass = exp(-2.621 + 2.456*log(dbh_cm))}#Finzi
  if(species == "PI") {biomass = exp(-2.621 + 2.456*log(dbh_cm))}#Finzi red spruce (PI= spruce)
  if(species == "PIAB") {biomass = exp(-2.621 + 2.456*log(dbh_cm))}#Finzi red spruce (Norway spruce)
  if(species == "PIGL") {biomass = exp(-2.621 + 2.456*log(dbh_cm))}#Finzi red spruce (white spruce)
  if(species == "PISP") {biomass = exp(-2.621 + 2.456*log(dbh_cm))}#Finzi red spruce (spruce spp.)
  #if(species == "PIST") {biomass = (exp(-0.04659059 + 2.545864 * log(dbh_cm/2.54)) + exp(-1.701115 + 2.485762 * log(dbh_cm/2.54)))/2.2 }
  if(species == "PIST") {biomass = exp(-3.293 + 2.603*log(dbh_cm))} #Finzi
  if(species == "PISY") {biomass = exp(-2.5356+2.4349*log(dbh_cm)) } #Jenkin's pine equation
  if(species == "POGR") {biomass = 0.0785*(dbh_cm^2.4981) } #Perala & Alban 1992 in Ter-Mik
  if(species == "POTR") {biomass = 0.0637*(dbh_cm^2.6087) } #Young et al. 1980 in Ter-Mik
  if(species=="POSP" ) {biomass<-0.0785*(dbh_cm^2.4981)  } #use P. grandidentata if Populous species is undefined
  #if(species == "PRPE") {biomass= (49.916 * (dbh_cm)^2.547)/1000 } #HF069, couldn't track down the equation source
  if(species == "PRPE") {biomass= (exp(0.9758 + 2.1948*log(dbh_cm/2.54)))/2.2 } #Young et al. 1980 in Jenkins
  if(species == "PRSE") {biomass= (1.8082 * (dbh_cm/2.54)^2.6174)/2.2  } #HF069, Brenneman et al. 1978 - excludes foliage, which is good but inconsistent with others. But I don't like the other options in Jenkins.
  if(species=="PRVI") { biomass = 0.2643 * (dbh_cm^1.7102)      } #Young et al. 1980 in Ter-Mik
  #if(species == "QUAL") {biomass = exp(-0.82061 + 2.84694 * log(dbh_cm/2.54)) }
  if(species == "QUAL") {biomass = exp(-2.520 + 2.590*log(dbh_cm))} #Finzi
  #if(species == "QUBI") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation
  if(species == "QUBI") {biomass = exp(-2.520 + 2.590*log(dbh_cm))} #Finzi Q. alba equation
  if(species=="QUCO") { biomass = 0.2482*(dbh_cm^2.19)    } #Whittaker & Woodwell 1968 in Ter-Mik
  #if(species == "QURU") {biomass = (exp(5.03 + 2.39 * log(dbh_cm)))/1000 }
  if(species == "QURU") {biomass = exp(-1.881 + 2.386*log(dbh_cm))} #Finzi
  #if(species == "QUVE") {biomass = (2.14567 * (dbh_cm/2.54)^2.50304)/2.2 }
  if(species == "QUVE") {biomass = exp(-2.821 + 2.659*log(dbh_cm))} #Finzi
  if(species=="ROPS" ) {biomass<-exp(-2.4800+2.4835*log(dbh_cm))      } #Robinia pseudoacacia, Jenkins mixed hardwood equation
  if(species == "SOAM") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation 
  if(species == "THOC") {biomass = exp(-2.5356+2.4349*log(dbh_cm))} #Jenkins pine equation
  #if(species == "TIAM") {biomass = 0.0872*dbh_cm^2.3539 } #Ter-Mik & Jenkins disagree on this one (Perala & Albans)
  if(species == "TIAM") {biomass= (1.4416 * (dbh_cm/2.54)^2.7324)/2.2  } #Brenneman et al. 1978 - excludes foliage, which is good but inconsistent with others. But I don't like the other options in Jenkins.
  #if(species == "TSCA") {biomass = (exp(0.2607714 + 2.366161 * log(dbh_cm/2.54)) + exp(-1.775095 + 2.703338 * log(dbh_cm/2.54)))/2.2}
  if(species == "TSCA") {biomass = exp(-2.2712 + 2.3444*log(dbh_cm))} #Finzi
  # NO if(species == "ULAM") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation - but Perala & Alban is for ULAM.
  if(species == "ULAM") {biomass = 0.0825 * dbh_cm^2.468   } #Perala & Alban in Jenkins
  if(species == "ULSP") {biomass = 0.0825 * dbh_cm^2.468   } #Perala & Alban in Jenkins
  if(species == "UNK") {biomass = exp(-2.4800+2.4835*log(dbh_cm)) } #Jenkins mixed hardwood equation
  return(biomass)
}

